Knobs class
- Inheritance
-
- Implemented types
-
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
hasListeners
→ bool
-
Whether any listeners are currently registered.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addListener(VoidCallback listener)
→ void
-
Register a closure to be called when the object changes.
inherited
-
all()
→ List<Knob>
-
-
boolean(String label, {bool initial = false})
→ bool
-
Creates checkbox with
label and initial value.
override
-
dispose()
→ void
-
Discards any resources used by the object.
inherited
-
get<T>(String label)
→ T
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners()
→ void
-
Call all the registered listeners.
inherited
-
number(String label, {num initial = 0})
→ num
-
override
-
options<T>(String label, {T? initial, List<Option<T>> options = const []})
→ T
-
Creates select field with
label, initial value and list of options.
override
-
removeListener(VoidCallback listener)
→ void
-
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
slider(String label, {double initial = 0, double max = 1, double min = 0})
→ double
-
override
-
text(String label, {String initial = ''})
→ String
-
Creates text input field with
label and initial value.
override
-
toString()
→ String
-
A string representation of this object.
inherited
-
update<T>(String label, T value)
→ void
-