SelectDefaultDynamic<T> class

Inheritance

Constructors

SelectDefaultDynamic({required List<T> options, required String getText(T?), BuildContext? context, DropDownSize? size, String getIcons(T?)?, bool inlineLabel = false, Color avatarColor = RothkoColor.kPrimaryBase, bool hasIcons = false, AvatarSize avatarSize = AvatarSize.normal, bool hasAvatarIcons = false, bool? networkIcons = false, void onChanged(T?)?, AutovalidateMode? autovalidateMode, Widget labelAction = const SizedBox(), T? selected, required String hintText, bool? focused = false, bool? readonly = false, dynamic onTap()?, bool? enabled = true, bool showTooltip = false, String? toolTipText = '', dynamic tooltipAction()?, Widget suffixIcon = const Icon(Icons.arrow_drop_down_rounded), required String labelText, Color? labelTextColor, String? validator(T?)?, double? labelTextSize, BorderSide? customBorder, double? width})

Properties

autovalidateMode → AutovalidateMode?
final
avatarColor → Color
final
avatarSize → AvatarSize
final
context → BuildContext?
final
customBorder → BorderSide?
final
enabled ↔ bool?
getter/setter pair
focused ↔ bool?
getter/setter pair
getIcons → String Function(T?)?
final
getText → String Function(T?)
final
hasAvatarIcons → bool
final
hashCode → int
The hash code for this object.
no setterinherited
hasIcons → bool
final
hintText → String
final
inlineLabel → bool
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
labelAction → Widget
final
labelText → String
final
labelTextColor → Color?
final
labelTextSize → double?
final
networkIcons → bool?
final
onChanged → void Function(T?)?
final
onTap ↔ dynamic Function()?
getter/setter pair
options → List<T>
final
readonly ↔ bool?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selected → T?
final
showTooltip → bool
final
size ↔ DropDownSize?
getter/setter pair
suffixIcon → Widget
final
tooltipAction ↔ dynamic Function()?
getter/setter pair
toolTipText → String?
final
validator → String? Function(T?)?
final
width → double?
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _SelectDefaultDynamicState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited