SelectDefault class

Inheritance

Constructors

SelectDefault({@required List<String>? options, BuildContext? context, void onChanged(String?)?, DropDownSize? size, AutovalidateMode? autovalidateMode, String? selected, String? hintText, bool? focused = false, bool? readonly = false, dynamic onTap()?, bool? enabled = true, Widget? suffixIcon, String? labelText, Color? labelTextColor, String? validator(String?)?, double? labelTextSize, BorderSide? customBorder, double? width})

Properties

autovalidateMode → AutovalidateMode?
final
context → BuildContext?
final
customBorder → BorderSide?
final
enabled ↔ bool?
getter/setter pair
focused ↔ bool?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hintText → String?
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
labelText → String?
final
labelTextColor → Color?
final
labelTextSize → double?
final
onChanged → void Function(String?)?
final
onTap ↔ dynamic Function()?
getter/setter pair
options → List<String>?
final
readonly ↔ bool?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selected → String?
final
size ↔ DropDownSize?
getter/setter pair
suffixIcon → Widget?
final
validator → String? Function(String?)?
final
width → double?
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _SelectDefaultState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited