TextFieldSuffixText class

Inheritance

Constructors

TextFieldSuffixText({@required String? label, int? maxlength, AutovalidateMode? autovalidateMode, IconData? suffixIcon, @required bool? readOnly, @required bool? enabled, String? helperHint, ValueChanged<String>? onChanged, List<TextInputFormatter>? inputFormatters, int? maxLines = 1, TextInputType? keyboardType, String? initialValue, String? validator(String?)?, bool enableSuggestions = false, @required String? suffixString, TextEditingController? textCtrl})

Properties

autovalidateMode ↔ AutovalidateMode?
getter/setter pair
enabled ↔ bool?
getter/setter pair
enableSuggestions ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
helperHint → String?
final
initialValue → String?
final
inputFormatters ↔ List<TextInputFormatter>?
getter/setter pair
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
keyboardType ↔ TextInputType?
getter/setter pair
label → String?
final
maxlength → int?
final
maxLines → int?
final
onChanged ↔ ValueChanged<String>?
getter/setter pair
readOnly ↔ bool?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
suffixIcon ↔ IconData?
getter/setter pair
suffixString → String?
final
textCtrl → TextEditingController?
final
validator ↔ String? Function(String?)?
getter/setter pair

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _TextFieldSuffixTextState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited