BubbleShape class

Inheritance

Constructors

BubbleShape({BubbleStyle style = BubbleStyle.fill, Color strokeColor = Colors.transparent, double strokeWidth = 0.5, ArrowDirection direction = ArrowDirection.bottom, double positionRatio = 0.5, double arrowHeight = 5.0, double arrowWidth = 8.0, double borderRadius = 10.0})

Properties

arrowHeight → double
final
arrowWidth → double
final
borderRadius → double
final
dimensions → EdgeInsetsGeometry
The widths of the sides of this border represented as an EdgeInsets.
no setteroverride
direction → ArrowDirection
final
hashCode → int
The hash code for this object.
no setterinherited
positionRatio → double
final
preferPaintInterior → bool
Reports whether paintInterior is implemented.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
strokeColor → Color
final
strokeWidth → double
final
style → BubbleStyle
final

Methods

add(ShapeBorder other, {bool reversed = false}) → ShapeBorder?
Attempts to create a new object that represents the amalgamation of this border and the other border.
inherited
getArrowHeightFit(Rect rect) → dynamic
getArrowWidthFit(Rect rect) → dynamic
getBorderRadiusFit(Rect rect) → dynamic
getInnerPath(Rect rect, {TextDirection? textDirection}) → Path
Create a Path that describes the inner edge of the border.
override
getOuterPath(Rect rect, {TextDirection? textDirection}) → Path
Create a Path that describes the outer edge of the border.
override
getPositionRatioFit(Rect rect) → dynamic
lerpFrom(ShapeBorder? a, double t) → ShapeBorder?
Linearly interpolates from another ShapeBorder (possibly of another class) to this.
inherited
lerpTo(ShapeBorder? b, double t) → ShapeBorder?
Linearly interpolates from this to another ShapeBorder (possibly of another class).
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(Canvas canvas, Rect rect, {TextDirection? textDirection}) → void
Paints the border within the given Rect on the given Canvas.
override
paintInterior(Canvas canvas, Rect rect, Paint paint, {TextDirection? textDirection}) → void
Paint a canvas with the appropriate shape.
inherited
scale(double t) → ShapeBorder
Creates a copy of this border, scaled by the factor t.
override
toString() → String
A string representation of this object.
inherited

Operators

operator +(ShapeBorder other) → ShapeBorder
Creates a new border consisting of the two borders on either side of the operator.
inherited
operator ==(Object other) → bool
The equality operator.
inherited